'// SLABHIDDevice.vb : main Visual Basic module file for
'// SLABHIDDevice.dll Version 1.5
'/////////////////////////////////////////////////////////////////////////////

'/////////////////////////////////////////////////////////////////////////////
'// Namespaces
'/////////////////////////////////////////////////////////////////////////////

Imports System.Text

'/////////////////////////////////////////////////////////////////////////////
'// SLABHIDDevice Module
'/////////////////////////////////////////////////////////////////////////////

Module SLABHIDDevice
    '/////////////////////////////////////////////////////////////////////////////
    '// Definitions
    '/////////////////////////////////////////////////////////////////////////////

    ' Return Codes
    Public Const HID_DEVICE_SUCCESS As Byte = &H0
    Public Const HID_DEVICE_NOT_FOUND As Byte = &H1
    Public Const HID_DEVICE_NOT_OPENED As Byte = &H2
    Public Const HID_DEVICE_ALREADY_OPENED As Byte = &H3
    Public Const HID_DEVICE_TRANSFER_TIMEOUT As Byte = &H4
    Public Const HID_DEVICE_TRANSFER_FAILED As Byte = &H5
    Public Const HID_DEVICE_CANNOT_GET_HID_INFO As Byte = &H6
    Public Const HID_DEVICE_HANDLE_ERROR As Byte = &H7
    Public Const HID_DEVICE_INVALID_BUFFER_SIZE As Byte = &H8
    Public Const HID_DEVICE_SYSTEM_CODE As Byte = &H9
    Public Const HID_DEVICE_UNSUPPORTED_FUNCTION As Byte = &HA
    Public Const HID_DEVICE_UNKNOWN_ERROR As Byte = &HFF

    ' Max number of USB Devices allowed
    Public Const MAX_USB_DEVICES As Byte = 64

    ' Max number of reports that can be requested at time
    Public Const MAX_REPORT_REQUEST_XP As UInteger = 512
    Public Const MAX_REPORT_REQUEST_2K As UInteger = 200
    Public Const DEFAULT_REPORT_INPUT_BUFFERS As UInteger = 0

    ' String Types
    Public Const HID_VID_STRING As Byte = &H1
    Public Const HID_PID_STRING As Byte = &H2
    Public Const HID_PATH_STRING As Byte = &H3
    Public Const HID_SERIAL_STRING As Byte = &H4
    Public Const HID_MANUFACTURER_STRING As Byte = &H5
    Public Const HID_PRODUCT_STRING As Byte = &H6

    ' String Lengths
    Public Const MAX_VID_LENGTH As UInteger = 5
    Public Const MAX_PID_LENGTH As UInteger = 5
    Public Const MAX_PATH_LENGTH As UInteger = 260
    Public Const MAX_SERIAL_STRING_LENGTH As UInteger = 256
    Public Const MAX_MANUFACTURER_STRING_LENGTH As UInteger = 256
    Public Const MAX_PRODUCT_STRING_LENGTH As UInteger = 256
    Public Const MAX_INDEXED_STRING_LENGTH As UInteger = 256
    Public Const MAX_STRING_LENGTH As UInteger = 260

    '/////////////////////////////////////////////////////////////////////////////
    '// SLABHIDDevice Functions
    '/////////////////////////////////////////////////////////////////////////////

    Public Declare Function HidDevice_GetNumHidDevices Lib "SLABHIDDevice.dll" (ByVal vid As UShort, ByVal pid As UShort) As UInteger
    Public Declare Function HidDevice_GetHidString Lib "SLABHIDDevice.dll" (ByVal deviceIndex As UInteger, ByVal vid As UShort, ByVal pid As UShort, ByVal hidStringType As Byte, ByVal deviceString As StringBuilder, ByVal deviceStringLength As UInteger) As Byte
    Public Declare Function HidDevice_GetHidIndexedString Lib "SLABHIDDevice.dll" (ByVal deviceIndex As UInteger, ByVal vid As UShort, ByVal pid As UShort, ByVal stringIndex As UInteger, ByVal deviceString As StringBuilder, ByVal deviceStringLength As UInteger) As Byte
    Public Declare Function HidDevice_GetHidAttributes Lib "SLABHIDDevice.dll" (ByVal deviceIndex As UInteger, ByVal vid As UShort, ByVal pid As UShort, ByRef deviceVid As UShort, ByRef devicePid As UShort, ByRef deviceReleaseNumber As UShort) As Byte
    Public Declare Sub HidDevice_GetHidGuid Lib "SLABHIDDevice.dll" (ByRef hidGuid As Guid)
    Public Declare Function HidDevice_GetHidLibraryVersion Lib "SLABHIDDevice.dll" (ByRef major As Byte, ByRef minor As Byte, ByRef release As Integer) As Byte
    Public Declare Function HidDevice_Open Lib "SLABHIDDevice.dll" (ByRef device As UInteger, ByVal deviceIndex As UInteger, ByVal vid As UShort, ByVal pid As UShort, ByVal numInputBuffers As UInteger) As Byte
    Public Declare Function HidDevice_IsOpened Lib "SLABHIDDevice.dll" (ByVal device As UInteger) As Integer
    Public Declare Function HidDevice_GetHandle Lib "SLABHIDDevice.dll" (ByVal device As UInteger) As UInteger
    Public Declare Function HidDevice_GetString Lib "SLABHIDDevice.dll" (ByVal device As UInteger, ByVal hidStringType As Byte, ByVal deviceString As StringBuilder, ByVal deviceStringLength As UInteger) As Byte
    Public Declare Function HidDevice_GetIndexedString Lib "SLABHIDDevice.dll" (ByVal device As UInteger, ByVal stringIndex As UInteger, ByVal deviceString As StringBuilder, ByVal deviceStringLength As UInteger) As Byte
    Public Declare Function HidDevice_GetAttributes Lib "SLABHIDDevice.dll" (ByVal device As UInteger, ByRef deviceVid As UShort, ByRef devicePid As UShort, ByRef deviceReleaseNumber As UShort) As Byte
    Public Declare Function HidDevice_SetFeatureReport_Control Lib "SLABHIDDevice.dll" (ByVal device As UInteger, ByVal buffer() As Byte, ByVal bufferSize As UInteger) As Byte
    Public Declare Function HidDevice_GetFeatureReport_Control Lib "SLABHIDDevice.dll" (ByVal device As UInteger, ByVal buffer() As Byte, ByVal bufferSize As UInteger) As Byte
    Public Declare Function HidDevice_SetOutputReport_Interrupt Lib "SLABHIDDevice.dll" (ByVal device As UInteger, ByVal buffer() As Byte, ByVal bufferSize As UInteger) As Byte
    Public Declare Function HidDevice_GetInputReport_Interrupt Lib "SLABHIDDevice.dll" (ByVal device As UInteger, ByVal buffer() As Byte, ByVal bufferSize As UInteger, ByVal numReports As UInteger, ByRef bytesReturned As UInteger) As Byte
    Public Declare Function HidDevice_SetOutputReport_Control Lib "SLABHIDDevice.dll" (ByVal device As UInteger, ByVal buffer() As Byte, ByVal bufferSize As UInteger) As Byte
    Public Declare Function HidDevice_GetInputReport_Control Lib "SLABHIDDevice.dll" (ByVal device As UInteger, ByVal buffer() As Byte, ByVal bufferSize As UInteger) As Byte
    Public Declare Function HidDevice_GetInputReportBufferLength Lib "SLABHIDDevice.dll" (ByVal device As UInteger) As UShort
    Public Declare Function HidDevice_GetOutputReportBufferLength Lib "SLABHIDDevice.dll" (ByVal device As UInteger) As UShort
    Public Declare Function HidDevice_GetFeatureReportBufferLength Lib "SLABHIDDevice.dll" (ByVal device As UInteger) As UShort
    Public Declare Function HidDevice_GetMaxReportRequest Lib "SLABHIDDevice.dll" (ByVal device As UInteger) As UInteger
    Public Declare Function HidDevice_FlushBuffers Lib "SLABHIDDevice.dll" (ByVal device As UInteger) As Integer
    Public Declare Function HidDevice_CancelIo Lib "SLABHIDDevice.dll" (ByVal device As UInteger) As Integer
    Public Declare Sub HidDevice_GetTimeouts Lib "SLABHIDDevice.dll" (ByVal device As UInteger, ByRef getReportTimeout As UInteger, ByRef setReportTimeout As UInteger)
    Public Declare Sub HidDevice_SetTimeouts Lib "SLABHIDDevice.dll" (ByVal device As UInteger, ByVal getReportTimeout As UInteger, ByVal setReportTimeout As UInteger)
    Public Declare Function HidDevice_Close Lib "SLABHIDDevice.dll" (ByVal device As UInteger) As Byte

End Module
